@@ -413,10 +413,17 @@ class Stacktrace(Interface):
     describing the context of that frame. Frames should be sorted from oldest
     to newest.
 
-    The stacktrace contains one element, ``frames``, which is a list of hashes. Each
+    The stacktrace contains an element, ``frames``, which is a list of hashes. Each
     hash must contain **at least** the ``filename`` attribute. The rest of the values
     are optional, but recommended.
 
+    Additionally, if the list of frames is large, you can explicitly tell the
+    system that you've omitted a range of frames. The ``frames_omitted`` must
+    be a single tuple two values: start and end. For example, if you only
+    removed the 8th frame, the value would be (8, 9), meaning it started at the
+    8th frame, and went until the 9th (the number of frames omitted is
+    end-start). The values should be based on a one-index.
+
     The list of frames should be ordered by the oldest call first.
 
     Each frame must contain the following attributes:
@@ -474,17 +481,19 @@ class Stacktrace(Interface):
     >>>             "line4",
     >>>             "line5"
     >>>         ],
-    >>>     }]
+    >>>     }],
+    >>>     "frames_omitted": [13, 56]
     >>> }
 
     .. note:: This interface can be passed as the 'stacktrace' key in addition
               to the full interface path.
     """
-    attrs = ('frames',)
+    attrs = ('frames', 'frames_omitted')
     score = 1000
 
     def __init__(self, frames, **kwargs):
         self.frames = [Frame(**f) for f in frames]
+        self.frames_omitted = kwargs.get('frames_omitted')
 
     def __iter__(self):
         return iter(self.frames)
@@ -493,6 +502,7 @@ class Stacktrace(Interface):
         for frame in self.frames:
             # ensure we've got the correct required values
             assert frame.is_valid()
+        assert self.frames_omitted is None or len(self.frames_omitted) == 2
 
     def serialize(self):
         frames = []
@@ -505,6 +515,7 @@ class Stacktrace(Interface):
 
         return {
             'frames': frames,
+            'frames_omitted': self.frames_omitted,
         }
 
     def has_app_frames(self):
@@ -512,6 +523,7 @@ class Stacktrace(Interface):
 
     def unserialize(self, data):
         data['frames'] = [Frame(**f) for f in data.pop('frames', [])]
+        data['frames_omitted'] = data.pop('frames_omitted', None)
         return data
 
     def get_composite_hash(self, interfaces):
@@ -553,6 +565,11 @@ class Stacktrace(Interface):
         if newest_first:
             frames = frames[::-1]
 
+        if self.frames_omitted:
+            first_frame_omitted, last_frame_omitted = self.frames_omitted
+        else:
+            first_frame_omitted, last_frame_omitted = None, None
+
         context = {
             'is_public': is_public,
             'newest_first': newest_first,
@@ -560,6 +577,8 @@ class Stacktrace(Interface):
             'event': event,
             'frames': frames,
             'stack_id': 'stacktrace_1',
+            'first_frame_omitted': first_frame_omitted,
+            'last_frame_omitted': last_frame_omitted,
         }
         if with_stacktrace:
             context['stacktrace'] = self.get_traceback(event, newest_first=newest_first)
@@ -998,7 +1017,6 @@ class Http(Interface):
             'full_url': '?'.join(filter(bool, [self.url, self.query_string])),
             'url': self.url,
             'method': self.method,
-            'data': data,
             'query_string': self.query_string,
             'headers': self.headers,
         }
@@ -1009,6 +1027,7 @@ class Http(Interface):
             context.update({
                 'cookies': cookies,
                 'env': self.env,
+                'data': data,
             })
 
         return render_to_string('sentry/partial/interfaces/http.html', context)
