@@ -57,7 +57,7 @@ def get_widgets(group, request):
 
 
 @register.filter
-def get_tags(group, request):
+def get_tags(group, request=None):
     project = group.project
 
     tag_list = []
@@ -105,4 +105,8 @@ def get_plugins(project):
 
 @register.filter
 def get_plugins_with_status(project):
-    return [(plugin, safe_execute(plugin.is_enabled, project)) for plugin in plugins.all()]
+    return [
+        (plugin, safe_execute(plugin.is_enabled, project))
+        for plugin in plugins.all()
+        if plugin.can_enable_for_projects()
+    ]
