@@ -2,13 +2,14 @@
 sentry.utils.dates
 ~~~~~~~~~~~~~~~~~~
 
-:copyright: (c) 2010-2012 by the Sentry Team, see AUTHORS for more details.
+:copyright: (c) 2010-2013 by the Sentry Team, see AUTHORS for more details.
 :license: BSD, see LICENSE for more details.
 """
 from datetime import datetime
 from dateutil.parser import parse
 from django.db import connections
 
+from sentry.constants import MINUTE_NORMALIZATION
 from sentry.utils.db import get_db_engine
 
 DATE_TRUNC_GROUPERS = {
@@ -51,3 +52,9 @@ def parse_date(datestr, timestr):
             return parse(datetimestr)
         except Exception:
             return
+
+
+def normalize_datetime(datetime, minutes=MINUTE_NORMALIZATION):
+    minutes = (datetime.minute - (datetime.minute % minutes))
+    normalized_datetime = datetime.replace(second=0, microsecond=0, minute=minutes)
+    return normalized_datetime
